==> haskell-http2-1.6.3-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.3
id: http2-1.6.3-ESQqlc866JN8l6dW4DZzjn
key: http2-1.6.3-ESQqlc866JN8l6dW4DZzjn
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
abi: 4042757097ce216ea8d948845013dfbf
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/http2-1.6.3
hs-libraries: HShttp2-1.6.3-ESQqlc866JN8l6dW4DZzjn
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb containers-0.5.7.1
    psqueues-0.2.2.3-8KktaatqvmQ9bEbz13fJDx
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-1.6.3-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.3
id: http2-1.6.3-BeepdVnoVJt7TSOBmebhvS
key: http2-1.6.3-BeepdVnoVJt7TSOBmebhvS
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
abi: 099f7c7adf09b68fc1499ac19cd4b36e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/http2-1.6.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/http2-1.6.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/http2-1.6.3
hs-libraries: HShttp2-1.6.3-BeepdVnoVJt7TSOBmebhvS
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.10-FRqGPugKcXCDhucdrD5I1k containers-0.5.7.1
    psqueues-0.2.2.3-EXJi1ksJea62s2kRGL7ryb
    stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
